#!/usr/bin/env python
# $Id$
''' Simple functions to get some network info from a machine '''

import os
import socket, fcntl, struct

def get_ip_address(ifname):
    ''' Use Linux SIOCGIFADDR ioctl to find the IP address of a device '''
    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    try:
        ipctl = fcntl.ioctl(sock.fileno(), 
                            0x8915, # SIOCGIFADDR
                            struct.pack('256s', ifname[:15])
                           )[20:24]
        return socket.inet_ntoa(ipctl)
    except IOError:
        return False

def get_host_name(ifname):
    ''' Return host name associated with a particular device '''
    try:
        return socket.gethostbyaddr(get_ip_address(ifname))[0]
    except socket.herror or TypeError:
        return "nohostname.nodomain"

def get_net_devices():
    ''' Enumerate all network devices '''
    for ifname in os.listdir("/sys/class/net"):
        yield ifname

def get_active_net_devices():
    ''' Enumerate all active network devices '''
    for ifname in get_net_devices():
        if get_ip_address(ifname):
            yield ifname

if __name__ == "__main__":
    for interface in get_active_net_devices():
        print get_host_name(interface) + ':',
        print interface + ' => ',
        print get_ip_address(interface)

# vim:syntax=python
# vim:sw=4:softtabstop=4:expandtab
